aboutsummaryrefslogtreecommitdiff
path: root/sys/dev/isp/ispvar.h
diff options
context:
space:
mode:
authorMatt Jacob <mjacob@FreeBSD.org>2007-01-20 04:00:21 +0000
committerMatt Jacob <mjacob@FreeBSD.org>2007-01-20 04:00:21 +0000
commit6c81a0aecb6ec9d28c78bb2dc9e12a7416fc6ac7 (patch)
tree792fae0deb725a4903b51a0a3ecacd02fad8422b /sys/dev/isp/ispvar.h
parentab86b1c667be221fd6939e41c142b87ba961cb22 (diff)
downloadsrc-6c81a0aecb6ec9d28c78bb2dc9e12a7416fc6ac7.tar.gz
src-6c81a0aecb6ec9d28c78bb2dc9e12a7416fc6ac7.zip
MFP4: Move default setting to the end of isp_reset instead of the
front of isp_init so we can read NVRAM even if we're role ISP_NONE. Prepare for reintroduction of channels (for FC) for N-Port Virtualization. Fix a botch in handle assignment that caused us to nuke one device when a new one arrives and end up with two devices with the same identity in the virtual target mapping table.
Notes
Notes: svn path=/head/; revision=166120
Diffstat (limited to 'sys/dev/isp/ispvar.h')
-rw-r--r--sys/dev/isp/ispvar.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/sys/dev/isp/ispvar.h b/sys/dev/isp/ispvar.h
index a5d7a98cbda5..306307b8aa0e 100644
--- a/sys/dev/isp/ispvar.h
+++ b/sys/dev/isp/ispvar.h
@@ -380,8 +380,8 @@ typedef struct {
uint8_t isp_reserved;
uint16_t isp_maxalloc;
uint16_t isp_maxfrmlen;
- uint64_t isp_nodewwn;
- uint64_t isp_portwwn;
+ uint64_t isp_wwnn_nvram;
+ uint64_t isp_wwpn_nvram;
/*
* Our Port Data Base
@@ -980,25 +980,25 @@ int isp_async(ispsoftc_t *, ispasync_t, void *);
*
*
* DEFAULT_IID(ispsoftc_t *) Default SCSI initiator ID
- * DEFAULT_LOOPID(ispsoftc_t *) Default FC Loop ID
- * DEFAULT_NODEWWN(ispsoftc_t *) Default Node WWN
- * DEFAULT_PORTWWN(ispsoftc_t *) Default Port WWN
- * DEFAULT_FRAMESIZE(ispsoftc_t *) Default Frame Size
+ * DEFAULT_LOOPID(ispsoftc_t *) Default FC Loop ID
+ * DEFAULT_NODEWWN(ispsoftc_t *) Default Node WWN
+ * DEFAULT_PORTWWN(ispsoftc_t *) Default Port WWN
+ * DEFAULT_FRAMESIZE(ispsoftc_t *) Default Frame Size
* DEFAULT_EXEC_THROTTLE(ispsoftc_t *) Default Execution Throttle
* These establish reasonable defaults for each platform.
* These must be available independent of card NVRAM and are
* to be used should NVRAM not be readable.
*
- * ISP_NODEWWN(ispsoftc_t *) FC Node WWN to use
- * ISP_PORTWWN(ispsoftc_t *) FC Port WWN to use
+ * ISP_NODEWWN(ispsoftc_t *) FC Node WWN to use
+ * ISP_PORTWWN(ispsoftc_t *) FC Port WWN to use
*
* These are to be used after NVRAM is read. The tags
* in fcparam.isp_{node,port}wwn reflect the values
* read from NVRAM (possibly corrected for card botches).
* Each platform can take that information and override
* it or ignore and return the Node and Port WWNs to be
- * used when sending the Qlogic f/w the Initialization Control
- * Block.
+ * used when sending the Qlogic f/w the Initialization
+ * Control Block.
*
* (XXX these do endian specific transformations- in transition XXX)
*
@@ -980,25 +980,25 @@ int isp_async(ispsoftc_t *, ispasync_t, void *);
*
* These are to be used after NVRAM is read. The tags
- * in fcparam.isp_{node,port}wwn reflect the values
+ * in fcparam.isp_ww{n,p}n_nvram reflect the values
* read from NVRAM (possibly corrected for card botches).
* Each platform can take that information and override